@@ -115,7 +115,7 @@
 ##    Z = Nxq matrix of covariates (one for each column), where q is the number of
 ##         covariates in the model.
 ##  output:
-##    coeflin = estimated QMLE coefficients
+##    coefs = estimated QMLE coefficients
 ##    selin = standard errors estimates
 ##    tlin = t test estimates
 ##    score = value of the score at the optimization point
@@ -132,9 +132,9 @@ log_lin_estimnarpq <- function(y, W, p, Z = NULL, uncons = FALSE, init = NULL, x
 
   if ( !is.null(Z) ) {
     Z <- model.matrix( ~., as.data.frame(Z) )
-    Z <- Z[1:dim(y)[1], -1, drop = FALSE]
+    Z <- Z[1:dim(y)[2], -1, drop = FALSE]
   }
-
+  y <- t(y)
   W <- W / Rfast::rowsums(W)
   W[ is.na(W) ] <- 0
 
@@ -207,7 +207,17 @@ log_lin_estimnarpq <- function(y, W, p, Z = NULL, uncons = FALSE, init = NULL, x
   qic_lins <- 2 * sum(H_lins * V_lins ) + 2 * s_qmle$objective
 
   coeflog <- cbind(coeflin, SE_lins, tlin, pval)
-  colnames(coeflog) <- c("Estimate", "Std. Error", "Z-stat", "p-value")
+  colnames(coeflog) <- c("Estimate", "Std. Error", "z value", "Pr(>|z|)")
+  coeflog <- as.data.frame(coeflog)
+  a <- pval
+  a[ which(pval > 0.1) ]   <- c("   ")
+  a[ which(pval < 0.1) ]   <- c(".  ")
+  a[ which(pval < 0.05) ]  <- c("*  ")
+  a[ which(pval < 0.01) ]  <- c("** ")
+  a[ which(pval < 0.001) ] <- c("***")
+  coeflog <- cbind(coeflog, a)
+  colnames(coeflog)[5] <- ""
+
   if ( !is.null( dim(Z) ) ) {
     rownames(coeflog) <- rownames(S_lins) <- c( "beta0", paste("beta1", 1:p, sep =""), paste("beta2", 1:p, sep =""),
                                                 paste("delta", 1:dim(Z)[2], sep ="") )
@@ -227,7 +237,9 @@ log_lin_estimnarpq <- function(y, W, p, Z = NULL, uncons = FALSE, init = NULL, x
  #   }
  # }
 
-  list( coeflog = coeflog, score = S_lins, loglik = loglik, ic = ic )
+  result <- list( coefs = coeflog, score = S_lins, loglik = loglik, ic = ic )
+  class(result) <- "PNAR"
+  return(result)
 }
 
 
