@@ -36,37 +36,39 @@ poisson.MODpq.nonlin <- function(b, W, gama, p, d, Z = NULL, TT, N, copula = "ga
   } else  cholR <- NULL   ##  end  if ( copula != "clayton" )  {
 
   for ( ti in 1:p) {
-    u <- rcopula(n, N, copula, corrtype, rho, dof, cholR )
+    u <- PNAR::rcopula(n, N, copula, corrtype, rho, dof, cholR)
     x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-    y[, ti] <- getN(x, tt = 1)
+    y[, ti] <- PNAR::getN(x, tt = 1)
     i <- 0
     while ( sum( is.na(y[, ti]) ) > 0 ) {
       i <- i + 2
-      u <- rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR )
+      u <- PNAR::rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR)
       x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-      y[, ti] <- getN(x, tt = 1)
+      y[, ti] <- PNAR::getN(x, tt = 1)
     }
     ca[, ti] <- ( 1 + W %*% y[, ti] )^(-gama)
-    x <- u <- NULL
   }
 
   for ( ti in (p + 1):TT ) {
     X <- cbind(W %*% y[, (ti - 1):(ti - p)], y[, (ti - 1):(ti - p)], Z)
     lambda[, ti] <- b[1] * ca[, ti - d] + X %*% b[-1]
-    u <- rcopula(n, N, copula, corrtype, rho, dof, cholR )
+    u <- PNAR::rcopula(n, N, copula, corrtype, rho, dof, cholR)
     x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-    y[, ti] <- getN(x, tt = 1)
+    y[, ti] <- PNAR::getN(x, tt = 1)
     i <- 0
     while ( sum( is.na(y[, ti]) ) > 0 ) {
       i <- i + 2
-      u <- rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR )
+      u <- PNAR::rcopula(i * 100 + n, N, copula, corrtype, rho, dof, cholR)
       x <- Rfast::eachrow( log(u), -lambda[, ti], oper = "/" )
-      y[, ti] <- getN(x, tt = 1)
+      y[, ti] <- PNAR::getN(x, tt = 1)
     }
     ca[, ti] <- ( 1 + W %*% y[, ti] )^(-gama)
-    x <- u <- NULL
   }
 
+  x <- u <- NULL
+
+  lambda <- ts( t(lambda) )
+  y <- ts( t(y) )
   list(p2R = p2R, lambda = lambda, y = y)
 }
 
